def get_video_by_id(id: str) -> str:
    """
    Calculate the great circle distance between two points on the
    earth (specified in decimal degrees), returns the distance in
    meters.
    All arguments must be of equal length.
    :param id: video id
    :return: will return an object
    """

    return int(id) * 2



from setuptools import find_packages, setup

setup(
    name='statstube',
    packages=find_packages(include=['statstube']),
    version='1.0.1',
    description='This project aims to provide a proper and simpler way to crawl YouTube content.',
    long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='William Kana',
    author_email='',
    keyword='YouTube-Crawler',
    license='Apache-2.0 License',
    install_requires=[''],
    setup_requires=['pytest-runner==5.3.1'],
    tests_require=['pytest==7.0.0'],
    test_suite='tests',
)



from pathlib import Path
import pandas as pd

def get_setting_file():
    return Path('tst.txt').absolute()

def generate_file():
    data = {"names": ["go", "map", "filter"]}
    df = pd.DataFrame(data)
    df.to_csv("output" + "/" + "result", index=False)
